package com.persagy.apm.diagnose.indicatorcompute.controller;

import com.persagy.apm.diagnose.indicatorcompute.service.IProjectIndicatorComputeService;

import org.springframework.beans.factory.annotation.Autowired;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.persagy.apm.diagnose.indicatorcompute.model.*;
import com.persagy.apm.diagnose.indicatorcompute.model.vo.*;
import com.persagy.apm.diagnose.indicatorcompute.model.dto.*;
import com.persagy.apm.common.response.*;
import com.persagy.apm.common.utils.ResultHelper;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import javax.validation.Valid;
import java.util.List;

/**
 * 控制层
 * @author lixing
 * @version V1.0 2021-09-21 13:31:49
 */
@Api(tags = "") 
@Validated
@RestController
@RequestMapping("projectIndicatorComputes")
public class ProjectIndicatorComputeController {
    @Autowired
    private IProjectIndicatorComputeService projectIndicatorComputeService;

	@ApiOperation(value = "创建")
	@PostMapping("/create")
	public CommonResult<ApmResponseUpsertVO> createProjectIndicatorCompute(
	        @Valid @RequestBody AddProjectIndicatorComputeDTO addProjectIndicatorComputeDTO) {
        String id = projectIndicatorComputeService.createProjectIndicatorCompute(addProjectIndicatorComputeDTO);
        return ResultHelper.single(new ApmResponseUpsertVO(id));
	}
	
	@ApiOperation(value = "详情")
    @PostMapping("/get")
    public CommonResult<ProjectIndicatorComputeItemVO> queryProjectIndicatorComputeDetail(
            @Valid @RequestBody QueryProjectIndicatorComputeDetailDTO queryProjectIndicatorComputeDetailDTO) {
        ProjectIndicatorCompute projectIndicatorCompute = projectIndicatorComputeService.queryProjectIndicatorComputeDetail(queryProjectIndicatorComputeDetailDTO.getId());
        ProjectIndicatorComputeItemVO projectIndicatorComputeItemVO = ConvertProjectIndicatorComputeTool.INSTANCE.convert2ResponseItemDTO(projectIndicatorCompute);
        return ResultHelper.single(projectIndicatorComputeItemVO);
    }


    @ApiOperation(value = "更新")
    @PostMapping("/update")
    public CommonResult<ApmResponseUpsertVO> updateProjectIndicatorCompute(
            @Valid @RequestBody UpdateProjectIndicatorComputeDTO updateProjectIndicatorComputeDTO) {
        projectIndicatorComputeService.updateProjectIndicatorCompute(updateProjectIndicatorComputeDTO);
        return ResultHelper.single(new ApmResponseUpsertVO(updateProjectIndicatorComputeDTO.getId()));
    }


    @ApiOperation(value = "删除")
    @PostMapping("/delete")
    public CommonResult deleteProjectIndicatorCompute(
            @RequestBody @Valid DeleteProjectIndicatorComputeDTO deleteProjectIndicatorComputeDTO) {
        projectIndicatorComputeService.deleteProjectIndicatorCompute(deleteProjectIndicatorComputeDTO.getId());
        return ResultHelper.success();
    }


    @ApiOperation(value = "列表")
    @PostMapping("/query")
    public CommonResult<PageList<ProjectIndicatorComputeListItemVO>> queryProjectIndicatorCompute(
            @Valid @RequestBody QueryProjectIndicatorComputeDTO queryProjectIndicatorComputeDTO) {
        List<ProjectIndicatorCompute> projectIndicatorComputeList = projectIndicatorComputeService.queryProjectIndicatorComputeList(queryProjectIndicatorComputeDTO);
        List<ProjectIndicatorComputeListItemVO> resultList = ConvertProjectIndicatorComputeTool.INSTANCE.convert2List(projectIndicatorComputeList);
        return ResultHelper.multi(resultList);
    }
    
    //@ApiOperation(value = "列表, 分页查询")
    //@PostMapping("/query")
    //public CommonResult<PageList<ProjectIndicatorComputeListItemVO>> queryProjectIndicatorCompute(
    //        @Valid @RequestBody PageQueryProjectIndicatorComputeDTO pageQueryProjectIndicatorComputeDTO) {
    //    IPage<ProjectIndicatorCompute> pagedList = projectIndicatorComputeService.pageQueryProjectIndicatorCompute(pageQueryProjectIndicatorComputeDTO);
    //    IPage<ProjectIndicatorComputeListItemVO> pagedResultList = pagedList.convert(item -> {
    //        try {
    //           return ConvertProjectIndicatorComputeTool.INSTANCE.convert2ResponseListItemDTO(item);
    //        } catch (Exception e) {
    //            throw new IllegalArgumentException("分页查询，ProjectIndicatorCompute实体类转换为列表对象发生异常", e);
    //        }
    //    });
    //    return ResultHelper.multi(pagedResultList);
    //}
}

