package com.persagy.apm.diagnose.indicatorcompute.model;

import org.mapstruct.*;
import org.mapstruct.MappingTarget;
import org.mapstruct.factory.Mappers;
import com.persagy.apm.diagnose.indicatorcompute.model.vo.*;
import com.persagy.apm.diagnose.indicatorcompute.model.dto.*;

import java.util.List;

/**
 * (ProjectIndicatorCompute) dto、vo、do转换工具类
 * @author lixing
 * @version V1.0 2021-09-21 13:32:44
 */
@Mapper(nullValueMappingStrategy = NullValueMappingStrategy.RETURN_DEFAULT,
        nullValueCheckStrategy = NullValueCheckStrategy.ALWAYS)
public interface ConvertProjectIndicatorComputeTool {

    ConvertProjectIndicatorComputeTool INSTANCE = Mappers.getMapper(ConvertProjectIndicatorComputeTool.class);
    
    /**
    * do转换为ResponseItemVO
    *
    * @param projectIndicatorCompute do对象
    * @return ResponseItemVO
    * @author lixing
    * @version V1.0 2021-09-21 13:32:44
    */
    ProjectIndicatorComputeItemVO convert2ResponseItemDTO(ProjectIndicatorCompute projectIndicatorCompute);
    
    /**
    * do转换为ResponseListItemVO
    *
    * @param projectIndicatorCompute do对象
    * @return ResponseListItemVO
    * @author lixing
    * @version V1.0 2021-09-21 13:32:44
    */
    ProjectIndicatorComputeListItemVO convert2ResponseListItemDTO(ProjectIndicatorCompute projectIndicatorCompute);

    /**
    * do列表转换为ResponseListItemVO列表
    *
    * @param projectIndicatorComputeList do列表
    * @return ResponseListItemVO列表
    * @author lixing
    * @version V1.0 2021-09-21 13:32:44
    */
    List<ProjectIndicatorComputeListItemVO> convert2List(List<ProjectIndicatorCompute> projectIndicatorComputeList);
    
    /**
    * addDTO转换为do
    *
    * @param addProjectIndicatorComputeDTO addDTO
    * @return 要创建的do对象 
    * @author lixing
    * @version V1.0 2021-09-21 13:32:44
    */
    ProjectIndicatorCompute convertAddDto2Entity(AddProjectIndicatorComputeDTO addProjectIndicatorComputeDTO);
    
    /**
    * updateDTO转换为实体
    *
    * @param projectIndicatorCompute 更新前的do对象
    * @param updateProjectIndicatorComputeDTO updateDTO
    * @return 更新后的do对象
    * @author lixing
    * @version V1.0 2021-09-21 13:32:44
    */
    ProjectIndicatorCompute convertUpdateDto2Entity(@MappingTarget ProjectIndicatorCompute projectIndicatorCompute, UpdateProjectIndicatorComputeDTO updateProjectIndicatorComputeDTO);
}

