package com.persagy.apm.diagnose.indicatorrecord.service;

import com.persagy.apm.diagnose.indicatorcompute.model.ProjectIndicatorCompute;
import com.persagy.apm.diagnose.indicatorrecord.model.*;
import com.persagy.apm.diagnose.indicatorrecord.model.dto.*;

import java.util.List;
import java.util.concurrent.CountDownLatch;
import java.util.concurrent.Future;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.persagy.apm.diagnose.service.dto.ProjectDTO;
import com.persagy.framework.ems.data.pojo.hbase.MonitorIndicatorRecord;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.ibatis.annotations.Param;

/**
 * 监测指标历史记录(MonitorIndicatorRecord) service接口
 *
 * @author lixing
 * @version V1.0 2021-09-10 00:13:27
 */
public interface IMonitorIndicatorRecordService {




    /**
     * 查询监测指标历史记录
     *
     * @param queryMonitorIndicatorRecordDTO queryDTO
     * @return List<MonitorIndicatorRecord>
     * @author lixing
     * @version V1.0 2021-09-10 00:13:27
     */
    public List<MonitorIndicatorRecord> queryMonitorIndicatorRecordList(@Param("queryMonitorIndicatorRecordDTO") QueryMonitorIndicatorRecordDTO queryMonitorIndicatorRecordDTO) throws Exception;



    /**
     * @throws
     * @title computeIndicatorData
     * @description 异步计算项目指标数据
     * @author leifeng
     * @param: projectDTO
     * @param: projectIndicatorCompute
     * @param: latch
     * @updateTime 2021/9/21 14:31
     * @return: java.util.concurrent.Future<java.lang.String>
     */
    Future<String> computeIndicatorData(ProjectDTO projectDTO, ProjectIndicatorCompute projectIndicatorCompute, CountDownLatch latch) throws Exception;

    /**
     * @throws
     * @title sendIndicatorData
     * @description 异步发送指标数据
     * @author leifeng
     * @param: projectDTO
     * @param: latch
     * @updateTime 2021/9/25 16:32
     * @return: java.util.concurrent.Future<java.lang.String>
     */
    Future<String> sendIndicatorData(ProjectDTO projectDTO, CountDownLatch latch) throws Exception;

    /**
     * @throws
     * @title saveOrUpdateByPk
     * @description 根据表主键插入或更新记录, 主键为projectId, objId, 指标id, 时间
     * @author leifeng
     * @param: monitorIndicatorRecord
     * @updateTime 2021/9/27 11:07
     */
    public void saveOrUpdateByPk(MonitorIndicatorRecord monitorIndicatorRecord) throws Exception;

    /**
     * @throws
     * @title cleanAlarmConfig
     * @description 清除redis中报警定义缓存
     * @author leifeng
     * @updateTime 2021/9/28 3:07
     */
    public void cleanAlarmConfig(String projectId);

    /**
     * @throws
     * @title cleanAlarmConfig
     * @description 清除redis中报警定义缓存
     * @author leifeng
     * @updateTime 2021/9/28 3:07
     */
    public void cleanAlarmConfigSendTime(CleanAlarmConfigDTO cleanAlarmConfigDTO);

    public void saveDeleterOrUpdateByPk(MonitorIndicatorRecord monitorIndicatorRecord) throws Exception;

    void batchSaveMonitorIndicatorRecordList(List<MonitorIndicatorRecord> recordList)throws Exception;
}
