package com.persagy.apm.diagnose.service;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.persagy.apm.diagnose.constant.EnumValidType;
import com.persagy.apm.diagnose.feign.client.SaasWebClient;
import com.persagy.apm.diagnose.service.dto.ProjectDTO;
import com.persagy.apm.diagnose.service.vo.GroupVO;
import com.persagy.framework.tenant.mybatis.datasource.db.holder.SaasContext;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * OriginalPresent采集当前数据查询
 *
 * @author strootman
 * @version 1.0
 * @date 2018年8月17日
 */
@Service
public class SaasWebServiceImpl {

    private final static String USERID = "systemId";
    private final static String LOGINDEVICE = "PC";
    public static final String DEFAULT_PD = "123456";

//    @Value(value = "${energy.eq.run.system.code}")
//    private String systemCode;

    @Autowired
    SaasWebClient saasWebClient;

    /**
     * @throws
     * @title queryProjectDTOList
     * @description 通过运维平台查询有效状态项目list, projectIdList可以为空, 为空时查询全部
     * @author leifeng
     * @param: projectIdList
     * @updateTime 2021/9/20 20:07
     * @return: java.util.List<com.persagy.apm.diagnose.service.dto.ProjectDTO>
     */
    public List<ProjectDTO> queryProjectDTOList(List<String> projectIdList) throws Exception {
        JSONObject param = new JSONObject();
        JSONObject puser = new JSONObject();
        puser.put("userId", USERID);
        puser.put("loginDevice", LOGINDEVICE);
        param.put("puser", puser);
        param.put("groupCode", SaasContext.getContextGroupCode());
        if (!CollectionUtils.isEmpty(projectIdList)) {
            param.put("projectIds", projectIdList);
        }
        String resultStr = saasWebClient.queryInUseProjectsByIds(param.toJSONString());
        JSONObject parseObject = JSONObject.parseObject(resultStr);
        if ("failure".equals(parseObject.getString("result"))) {
            throw new Exception("查询分区失败：" + parseObject.getString("reson"));
        }
        List<ProjectDTO> result = new ArrayList<>();
        JSONArray jsonArray = parseObject.getJSONArray("content");
        if (jsonArray == null || jsonArray.isEmpty()) {
            return result;
        }

        for (Object object : jsonArray) {
            JSONObject obj = (JSONObject) object;
            ProjectDTO projectDTO = ProjectDTO.builder().projectId(obj.getString("projectId")).projectLocalId(obj.getString("projectLocalID")).build();
            result.add(projectDTO);
        }
        return result;
    }

    private List<ProjectDTO> queryProjectFromEmsSaasWeb(List<String> projectIdList) throws Exception {
        JSONObject param = new JSONObject();
        JSONObject puser = new JSONObject();
        puser.put("userId", USERID);
        puser.put("loginDevice", LOGINDEVICE);
        param.put("puser", puser);
        param.put("groupCode", SaasContext.getContextGroupCode());
        if (!CollectionUtils.isEmpty(projectIdList)) {
            param.put("projectIds", projectIdList);
        }
        String resultStr = saasWebClient.queryInUseProjectsByIds(param.toJSONString());
        JSONObject parseObject = JSONObject.parseObject(resultStr);
        if ("failure".equals(parseObject.getString("result"))) {
            throw new Exception("查询分区失败：" + parseObject.getString("reson"));
        }
        List<ProjectDTO> result = new ArrayList<>();
        JSONArray jsonArray = parseObject.getJSONArray("content");
        if (jsonArray == null || jsonArray.isEmpty()) {
            return result;
        }

        for (Object object : jsonArray) {
            JSONObject obj = (JSONObject) object;
            ProjectDTO projectDTO = ProjectDTO.builder().projectId(obj.getString("projectId")).projectLocalId(obj.getString("projectLocalID")).build();
            result.add(projectDTO);
        }
        return result;
    }

    public List<ProjectDTO> getProjectByIdService(String projectId) throws Exception {
        JSONObject param = new JSONObject();
        JSONObject puser = new JSONObject();
        puser.put("userId", USERID);
        puser.put("loginDevice", LOGINDEVICE);
        puser.put("pd", DEFAULT_PD);
        param.put("puser", puser);
        param.put("groupCode", SaasContext.getContextGroupCode());
        param.put("projectId", projectId);
        String resultStr = saasWebClient.getProjectByIdService(param.toJSONString());
        JSONObject parseObject = JSONObject.parseObject(resultStr);
        if ("failure".equals(parseObject.getString("result"))) {
            throw new Exception("查询分区失败：" + parseObject.getString("reson"));
        }
        List<ProjectDTO> result = new ArrayList<>();
        JSONArray jsonArray = parseObject.getJSONArray("content");
        if (jsonArray == null || jsonArray.isEmpty()) {
            return result;
        }

        for (Object object : jsonArray) {
            JSONObject obj = (JSONObject) object;
            ProjectDTO projectDTO = ProjectDTO.builder().projectId(obj.getString("projectId")).projectLocalId(obj.getString("projectLocalID")).build();
            result.add(projectDTO);
        }
        return result;
    }

    public List<GroupVO> queryValidGroupList() throws Exception {
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("status", EnumValidType.YES.getCode());
        JSONObject result = JSONObject.parseObject(saasWebClient.queryGroupList(jsonObject));
        if ("failure".equals(result.getString("Result"))) {
            throw new Exception("查询集团失败：" + result.getString("ResultMsg"));
        }
        JSONArray groupJSONArray = result.getJSONArray("Content");
        if (groupJSONArray.isEmpty()) {
            return new ArrayList<>();
        }
        return JSONObject.parseArray(groupJSONArray.toJSONString(), GroupVO.class);
    }

}
