package com.persagy.apm.diagnose.service;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.persagy.apm.diagnose.maintenance.model.dto.WeatherDTO;
import com.persagy.apm.diagnose.utils.HttpUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 天气服务
 */
@Service
@Slf4j
public class WeatherServiceImpl {

    /**
     * 天气服务
     */
    @Value(value = "${weather.server}")
    public String emsWeatherServer;
    private static final String SUCCESS = "success";
    /**
     * 天气服务系统-获取历史小时天气 最大支持查询7天的数据。
     */
    public static final String HOUR_HISTORY_DATA = "/Spring/MVC/entrance/unifier/HourHistoryData";

    public List<WeatherDTO> hourHistoryData(String cityCode, String startTimeStr, String endTimeStr, Boolean minResponse, int reqCount) throws Exception {
        String requestUrl = emsWeatherServer + HOUR_HISTORY_DATA;
        JSONObject param = new JSONObject();
        param.put("cityCode", cityCode);
        param.put("startTime", startTimeStr);
        param.put("endTime", endTimeStr);
        param.put("minResponse", minResponse);

        Map<String, Object> paramMap = new HashMap<>();
        paramMap.put("jsonString", param);

        try {
            String result = HttpUtils.httpPostFormUrlencoded(requestUrl, paramMap);

            JSONObject resultObj = JSONObject.parseObject(result, JSONObject.class);

            if (!resultObj.getString("result").equalsIgnoreCase(SUCCESS)) {
                log.error("查询室外小时天气历史数据返回结果：{}", result);
            /*// todo 由于在没有数据情况下接口返回也是失败，但是其实是成功，所以不抛异常
            if (null != resultObj.get("reason")) {
                throw new Exception("查询小时天气历史数据请求返回失败");
            }*/
                return new ArrayList<>();
               // throw new Exception("查询小时天气历史数据请求返回失败");
            }
            List<JSONObject> jsonObjectList = JSON.parseArray(JSON.toJSONString(resultObj.get("content")), JSONObject.class);
            if (!CollectionUtils.isEmpty(jsonObjectList)){
                List<WeatherDTO> weatherDTOList = new ArrayList<>();
                for (JSONObject obj:jsonObjectList) {
                    //温湿度 任意为空 跳过
                    if (null == obj.getDouble("temperature") || null == obj.getDouble("humidity")){
                        continue;
                    }
                    WeatherDTO dto = new WeatherDTO();
                    dto.setHourTime(obj.getDate("hourTime"));
                    dto.setTemperature(obj.getDouble("temperature"));
                    dto.setHumidity(obj.getDouble("humidity"));
                    weatherDTOList.add(dto);
                }
                return weatherDTOList;
            }
        } catch (Exception e) {
            log.error("---------获取室外小时天气历史数据出错了---------");
            log.error("出错的请求路径是：{}", requestUrl);
            log.error("出错的请求参数是：{}", JSON.toJSONString(paramMap));
            // 重试
            Thread.sleep(100);
            if (reqCount < 5) {
                return hourHistoryData(cityCode, startTimeStr, endTimeStr, minResponse, reqCount + 1);
            }
           // throw new Exception("查询小时天气历史数据请求出错");
        }
        return new ArrayList<>();
    }
}
