package com.persagy.apm.diagnose.service.schedule;

import com.persagy.apm.diagnose.service.MaintenanceDataService;
import com.persagy.apm.diagnose.service.SaasWebServiceImpl;
import com.persagy.apm.diagnose.service.vo.GroupVO;
import com.persagy.framework.tenant.mybatis.datasource.db.holder.SaasContext;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 计算 设备维保  日维度数据
 */

@Slf4j
@Service
public class ComputeMaintenanceData {

    @Value("${compute.maintenance.data.enable:false}")
    private boolean enable;

    @Autowired
    private MaintenanceDataService maintenanceDataService;
    @Autowired
    private SaasWebServiceImpl saasWebService;

    @Scheduled(cron="${compute.maintenance.data.cron:0 10 0 * * ?}")
    public void computeMaintenanceData() throws Exception {
        if (!enable) {
            //计算未开启
            return;
        }
        //获取有效集团编码
        List<GroupVO> groupVOList = saasWebService.queryValidGroupList();
        if (CollectionUtils.isEmpty(groupVOList)){
            log.error("【计算设备维保日维度平均值数据线程】:无有效集团.......");
            return;
        }
        log.error("【计算设备维保日维度平均值数据线程】:计算数据开始.......");
        for (GroupVO group:groupVOList) {
            log.info("【计算设备维保日维度平均值数据线程】:集团{}开始.......",group.getCode());
            try {
                SaasContext.setContextGroupCode(group.getCode());
            }catch (Exception e){
                continue;
            }
            maintenanceDataService.computeMaintenanceData();
            log.info("【计算设备维保日维度平均值数据线程】:集团{}结束.......",group.getCode());
        }
        log.error("【计算设备维保日维度平均值数据线程】:计算数据结束.......");
    }
}
