package com.persagy.apm.diagnose.service.schedule;

import com.persagy.apm.diagnose.service.ComputeIndicatorDataService;
import com.persagy.apm.diagnose.service.SaasWebServiceImpl;
import com.persagy.apm.diagnose.service.vo.GroupVO;
import com.persagy.framework.tenant.mybatis.datasource.db.holder.SaasContext;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author king
 */
@Slf4j
@Service
public class SendIndicatorData {

    @Value("${eyd.send.indicator.data.enabel:false}")
    private boolean enable;

    @Autowired
    private ComputeIndicatorDataService computeIndicatorDataService;
    @Autowired
    private SaasWebServiceImpl saasWebService;

    @Scheduled(cron="${eyd.send.indicator.data.cron:*/5 * * * * ?}")
    public void computeIndicatorData() throws Exception {
    	if (!enable) {
    	    //指标计算未开启
    	    return;
		}
        //获取有效集团编码
        List<GroupVO> groupVOList = saasWebService.queryValidGroupList();
        if (CollectionUtils.isEmpty(groupVOList)){
            log.error("【发送监测指标数据线程】:无有效集团.......");
            return;
        }
        log.error("【发送监测指标数据线程】:发送指标数据开始.......");
        for (GroupVO group:groupVOList) {
            log.info("【发送监测指标数据线程】:集团{}开始.......",group.getCode());
            try {
                SaasContext.setContextGroupCode(group.getCode());
            }catch (Exception e){
                continue;
            }
            computeIndicatorDataService.sendIndicatorData();
            log.info("【发送监测指标数据线程】:集团{}结束.......",group.getCode());
        }
        log.error("【发送监测指标数据线程】:发送指标数据结束.......");
    }
}
