package com.persagy.apm.diagnose.service.schedule;

import com.persagy.apm.diagnose.service.MaintenanceDataService;
import com.persagy.apm.diagnose.service.SaasWebServiceImpl;
import com.persagy.apm.diagnose.service.vo.GroupVO;
import com.persagy.framework.tenant.mybatis.datasource.db.holder.SaasContext;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 同步 检查即将报废设备
 */
@Slf4j
@Service
public class SyncCheckGoingDestroyEquip {

    @Value("${sync.check.going.destroy.equip.enable:false}")
    private boolean enable;

    @Autowired
    private MaintenanceDataService maintenanceDataService;
    @Autowired
    private SaasWebServiceImpl saasWebService;

    @Scheduled(cron="${sync.check.going.destroy.equip.cron:0 10 0 * * ?}")
    public void syncCheckGoingDestroyEquip() throws Exception {
        if (!enable) {
            //同步未开启
            return;
        }
        //获取有效集团编码
        List<GroupVO> groupVOList = saasWebService.queryValidGroupList();
        if (CollectionUtils.isEmpty(groupVOList)){
            log.error("【同步检查即将报废设备线程】:无有效集团.......");
            return;
        }
        log.error("【同步检查即将报废设备线程】:同步检查即将报废设备开始.......");
        for (GroupVO group:groupVOList) {
            log.info("【同步检查即将报废设备线程】:集团{}开始.......",group.getCode());
            try {
                SaasContext.setContextGroupCode(group.getCode());
            }catch (Exception e){
                continue;
            }
            maintenanceDataService.syncCheckGoingDestroyEquip();
            log.info("【同步检查即将报废设备线程】:集团{}结束.......",group.getCode());
        }
        log.error("【同步检查即将报废设备线程】:同步检查即将报废设备开始.......");
    }
}
